<?php

/**
 * This is the model class for table "pc_activity".
 *
 * The followings are the available columns in table 'pc_activity':
 * @property integer $pca_id
 * @property integer $pca_user_id
 * @property string $pca_email
 * @property integer $pca_status
 * @property string $pca_created_date
 * @property string $pca_approved_date
 */
class Activity extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'pc_activity';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(

			array('pca_id, pca_user_id, pca_status', 'numerical', 'integerOnly'=>true),
			array('pca_email', 'length', 'max'=>64),
			array('pca_created_date, pca_approved_date', 'length', 'max'=>32),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('pca_id, pca_user_id, pca_email, pca_status, pca_created_date, pca_approved_date', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'pca_id' => 'Pca',
			'pca_user_id' => 'User',
			'pca_email' => 'Email',
			'pca_status' => 'Status',
			'pca_created_date' => 'Created Date',
			'pca_approved_date' => 'Approved Date',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function admin_activity_search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('pca_id',$this->pca_id);
		$criteria->compare('pca_user_id',$this->pca_user_id);
		$criteria->compare('pca_email',$this->pca_email,true);
		$criteria->compare('pca_status',$this->pca_status);
		$criteria->compare('pca_created_date',$this->pca_created_date,true);
		$criteria->compare('pca_approved_date',$this->pca_approved_date,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Activity the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
