<?php

/**
 * This is the model class for table "pc_banks".
 *
 * The followings are the available columns in table 'pc_banks':
 * @property integer $pcb_id
 * @property string $pcb_bankname
 * @property string $pcb_holdername
 * @property string $pcb_account_no
 * @property string $pcb_address
 * @property integer $pcb_city
 * @property integer $pcb_country
 * @property integer $pcb_state
 * @property string $pcb_zipcode
 * @property string $pcb_phone_no
 * @property integer $pcb_account_type
 * @property string $pcb_routing_no
 * @property string $pcb_bic
 * @property integer $pcb_status
 * @property integer $pcb_default
 * @property string $created_at
 * @property string $updated_at
 */
class Banks extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'pc_banks';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('pcb_bankname, pcb_holdername, pcb_account_no, pcb_address, pcb_city, pcb_country, pcb_state, pcb_zipcode, pcb_phone_no, pcb_account_type, pcb_routing_no, pcb_bic, pcb_status, pcb_default, created_at, updated_at', 'required'),
			array('pcb_city, pcb_country, pcb_state, pcb_account_type, pcb_status, pcb_default', 'numerical', 'integerOnly'=>true),
			array('pcb_bankname, pcb_holdername, pcb_account_no, pcb_address', 'length', 'max'=>255),
			array('pcb_zipcode', 'length', 'max'=>32),
			array('pcb_phone_no, pcb_routing_no', 'length', 'max'=>100),
			array('pcb_bic', 'length', 'max'=>24),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('pcb_id, pcb_bankname, pcb_holdername, pcb_account_no, pcb_address, pcb_city, pcb_country, pcb_state, pcb_zipcode, pcb_phone_no, pcb_account_type, pcb_routing_no, pcb_bic, pcb_status, pcb_default, created_at, updated_at', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'pcb_id' => 'Pcb',
			'pcb_bankname' => 'Pcb Bankname',
			'pcb_holdername' => 'Pcb Holdername',
			'pcb_account_no' => 'Pcb Account No',
			'pcb_address' => 'Pcb Address',
			'pcb_city' => 'Pcb City',
			'pcb_country' => 'Pcb Country',
			'pcb_state' => 'Pcb State',
			'pcb_zipcode' => 'Pcb Zipcode',
			'pcb_phone_no' => 'Pcb Phone No',
			'pcb_account_type' => 'Pcb Account Type',
			'pcb_routing_no' => 'Pcb Routing No',
			'pcb_bic' => 'Pcb Bic',
			'pcb_status' => 'Pcb Status',
			'pcb_default' => 'Pcb Default',
			'created_at' => 'Created At',
			'updated_at' => 'Updated At',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('pcb_id',$this->pcb_id);
		$criteria->compare('pcb_bankname',$this->pcb_bankname,true);
		$criteria->compare('pcb_holdername',$this->pcb_holdername,true);
		$criteria->compare('pcb_account_no',$this->pcb_account_no,true);
		$criteria->compare('pcb_address',$this->pcb_address,true);
		$criteria->compare('pcb_city',$this->pcb_city);
		$criteria->compare('pcb_country',$this->pcb_country);
		$criteria->compare('pcb_state',$this->pcb_state);
		$criteria->compare('pcb_zipcode',$this->pcb_zipcode,true);
		$criteria->compare('pcb_phone_no',$this->pcb_phone_no,true);
		$criteria->compare('pcb_account_type',$this->pcb_account_type);
		$criteria->compare('pcb_routing_no',$this->pcb_routing_no,true);
		$criteria->compare('pcb_bic',$this->pcb_bic,true);
		$criteria->compare('pcb_status',$this->pcb_status);
		$criteria->compare('pcb_default',$this->pcb_default);
		$criteria->compare('created_at',$this->created_at,true);
		$criteria->compare('updated_at',$this->updated_at,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Banks the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	public function beforeSave(){
		if($this->isNewRecord)
			$this->created_at	= date('Y-m-d H:i:s');
		else
			$this->updated_at	= date('Y-m-d H:i:s');

		return true;
	}
}
