<?php

/**
 * This is the model class for table "pc_inout_transactions".
 *
 * The followings are the available columns in table 'pc_inout_transactions':
 * @property integer $pcit_id
 * @property string $pcit_to
 * @property double $pcit_amount
 * @property integer $pcit_type
 * @property double $pcit_charges
 * @property string $pcit_currency
 * @property integer $pcit_status
 * @property string $pcit_createddate
 */
class InoutTransactions extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'pc_inout_transactions';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('pcit_to', 'required','on'=>'add,sendmoneyprocess'),
			array('pcit_to', 'required','on'=>'sendmoney'),
			array('pcit_to', 'checkEmailSame','on'=>'add,sendmoney'),
			array('pcit_amount', 'checkBalance','on'=>'add,sendmoney,sendmoneyprocess'),
			array('pcit_amount', 'checklimitfunds','on'=>'sendmoneyprocess'),
			array('pcit_id, pcit_to, pcit_amount, pcit_note,pcit_type, pcit_charges, pcit_currency, pcit_exit_status,pcit_status, pcit_createddate', 'safe', 'on'=>'search,add,sendmoney,user_send_request_money_search,sendmoneyprocess'),
		);
	}

	public function checkEmailSame(){

		$dataCheck = Userdetails::model()->findAll('pcu_id =? AND pcu_email =?',array(Yii::app()->user->getState('Userid'),$this->pcit_to));
		
		$dataExistCheck = Userdetails::model()->findAll('pcu_email =?',array($this->pcit_to));

		if(count($dataCheck) > 0){
			return $this->addError('pcit_to','You cant send/request fund yourself.');
		} 

		if(count($dataExistCheck) == 0){
			return $this->addError('pcit_to','You cant send/request fund invalid address.');
		} 
	}

	public function checkBalance(){

		$dataCheck = Userdetails::model()->findAll('pcu_id =?',array(Yii::app()->user->getState('Userid')));
		
		if($dataCheck[0]['pcu_user_balance'] <= $this->pcit_amount){
			return $this->addError('pcit_amount','You dont have sufficient fund to complete this transaction.');
		} 
	}

	public function checklimitfunds(){

		$allow_limit = $total =  0;

		$dataCheck = Userdetails::model()->findAll('pcu_id =?',array(Yii::app()->user->getState('Userid')));

		$processed_amount=Yii::app()->db->createCommand("SELECT SUM(pcit_amount) as total FROM pc_inout_transactions WHERE pcit_userid = ".Yii::app()->user->getState('Userid')." AND DATE(pcit_createddate) = CURDATE() ORDER BY pcit_id DESC")->queryAll();

		$getLimitPerAc = Settings::model()->findAll('pcs_id =?',array(1));		
		$account_type = $dataCheck[0]['pcu_account_type'];
		
		if($account_type == 1)
			$allow_limit = $getLimitPerAc[0]['pcs_personal_per_limit'];
		 else
			$allow_limit = $getLimitPerAc[0]['pcs_busness_per_limit'];
		
		$total = $processed_amount[0]['total'];

		if( ($allow_limit >= $total) != TRUE){

			return $this->addError('pcit_amount','You dont have sufficient fund to complete this transaction / limit exceeds.');
		} 
	}
	
	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'UserRel' => array(self::BELONGS_TO, 'Userdetails', 'pcit_userid'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'pcit_id' => 'Pcit',
			'pcit_to' => 'To',
			'pcit_amount' => 'Amount',
			'pcit_type' => 'Type',
			'pcit_charges' => 'Charges',
			'pcit_currency' => 'Currency',
			'pcit_exit_status' => 'Transaction Status',
			'pcit_note' => 'Notes',
			'pcit_status' => 'Status',
			'pcit_createddate' => 'Created date',
			'pcit_transaction_id' => 'Transaction ID',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.
		$criteria=new CDbCriteria;
		$criteria->with = array('UserRel');
		$criteria->together = true;
		$criteria->compare('pcit_id',$this->pcit_id);
		$criteria->compare('pcit_transaction_id',$this->pcit_transaction_id);
		$criteria->compare('pcit_to',$this->pcit_to,true);
		$criteria->compare('pcit_amount',$this->pcit_amount);
		$criteria->compare('pcit_type',$this->pcit_type);
		$criteria->compare('pcit_exit_status',$this->pcit_exit_status);
		$criteria->compare('pcit_charges',$this->pcit_charges);
		$criteria->compare('pcit_currency',$this->pcit_currency,true);
		$criteria->compare('pcit_status',$this->pcit_status);
		$criteria->compare('pcit_createddate',$this->pcit_createddate,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
			'sort'=>array(
                        'defaultOrder'=>'pcit_id DESC',
                    ),
		));
	}

	public function admin_send_request_money_search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;
		$criteria->with = array('UserRel');
		$criteria->together = true;
		$criteria->compare('pcit_id',$this->pcit_id);
		$criteria->compare('pcit_userid',$this->pcit_userid);
		$criteria->compare('pcit_transaction_id',$this->pcit_transaction_id);
		$criteria->compare('pcit_exit_status',$this->pcit_exit_status);
		$criteria->compare('pcit_to',$this->pcit_to,true);
		$criteria->compare('pcit_amount',$this->pcit_amount);
		if(isset($_GET['type']) && $_GET['type'] != ''){

			$criteria->compare('pcit_type',$_GET['type']);
		} else
		{
			$criteria->compare('pcit_type',$this->pcit_type);
		}
		$criteria->compare('pcit_charges',$this->pcit_charges);
		$criteria->compare('pcit_currency',$this->pcit_currency,true);
		$criteria->compare('pcit_status',$this->pcit_status);
		$criteria->compare('pcit_createddate',$this->pcit_createddate,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
			'sort'=>array(
                        'defaultOrder'=>'pcit_createddate DESC',
                    ),
		));
	}

	public function user_send_request_money_search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.
		$criteria=new CDbCriteria;
		$criteria->with = array('UserRel');
		$criteria->together = true;
		$criteria->compare('pcit_id',$this->pcit_id);
		$criteria->compare('pcit_transaction_id',$this->pcit_transaction_id);
		$criteria->compare('pcit_exit_status',$this->pcit_exit_status);
		$criteria->compare('pcit_to',$this->pcit_to,true);
		$criteria->compare('pcit_amount',$this->pcit_amount);
		$criteria->compare('pcit_type',$this->pcit_type);
		$criteria->compare('pcit_charges',$this->pcit_charges);
		$criteria->compare('pcit_currency',$this->pcit_currency,true);
		$criteria->compare('pcit_status',$this->pcit_status);
		$criteria->compare('pcit_createddate',$this->pcit_createddate,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
			'sort'=>array(
                        'defaultOrder'=>'pcit_createddate DESC',
                    ),
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return InoutTransactions the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	public function beforeSave(){
		if($this->isNewRecord)
			$this->pcit_createddate	= date('Y-m-d H:i:s');
		else
			$this->pcit_updateddate	= date('Y-m-d H:i:s');

		return true;
	}
}
