<?php

/**
 * This is the model class for table "pc_user_apis".
 *
 * The followings are the available columns in table 'pc_user_apis':
 * @property integer $pcuas_id
 * @property integer $pcuas_userid
 * @property string $pcuas_name
 * @property string $pcuas_api_key
 * @property string $pcuas_password
 * @property integer $pcuas_status
 * @property string $pcuas_created_date
 */
class UserApis extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'pc_user_apis';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('pcuas_name, pcuas_api_key, pcuas_password, pcuas_status', 'required','on'=>'addapi,updateApi'),
			array('pcuas_userid, pcuas_status', 'numerical', 'integerOnly'=>true ,'on'=>'addapi,updateApi'),
			array('pcuas_name, pcuas_api_key', 'length', 'max'=>255 ,'on'=>'addapi,updateApi'),
			array('pcuas_password', 'length', 'max'=>100 ,'on'=>'addapi,updateApi'),
			array('pcuas_name', 'unique' ,'on'=>'addapi'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('pcuas_id, pcuas_userid, pcuas_name, pcuas_api_key, pcuas_password, pcuas_status, pcuas_created_date', 'safe', 'on'=>'search,addapi,updateApi'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'pcuas_id' => 'Pcuas',
			'pcuas_userid' => 'Pcuas Userid',
			'pcuas_name' => 'API Name',
			'pcuas_api_key' => 'Api Key',
			'pcuas_password' => 'Password',
			'pcuas_status' => 'Status',
			'pcuas_created_date' => 'Created Date',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function user_api_search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('pcuas_id',$this->pcuas_id);
		$criteria->compare('pcuas_userid',$this->pcuas_userid);
		$criteria->compare('pcuas_name',$this->pcuas_name,true);
		$criteria->compare('pcuas_api_key',$this->pcuas_api_key,true);
		$criteria->compare('pcuas_password',$this->pcuas_password,true);
		$criteria->compare('pcuas_status',$this->pcuas_status);
		$criteria->compare('pcuas_created_date',$this->pcuas_created_date,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
			'sort'=>array(
                        'defaultOrder'=>'pcuas_id DESC',
                    ),
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return UserApis the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	public function beforeSave(){
		if($this->isNewRecord)
			$this->pcuas_created_date	= date('Y-m-d H:i:s');
		else
			$this->pcuas_created_date	= date('Y-m-d H:i:s');

		return true;
	}
}
