<?php

/**
 * This is the model class for table "pc_userdetails".
 *
 * The followings are the available columns in table 'pc_userdetails':
 * @property integer $pcu_id
 * @property integer $pcu_userid
 * @property string $pcu_firstname
 * @property string $pcu_middlename
 * @property string $pcu_lastname
 * @property integer $pcu_account_type
 * @property string $pcu_address1
 * @property string $pcu_address2
 * @property integer $pcu_country
 * @property integer $pcu_state
 * @property integer $pcu_city
 * @property integer $pcu_location
 * @property string $pcu_zipcode
 * @property integer $pcu_mobile
 * @property integer $pcu_mobile_verified
 * @property integer $pcu_email_verified
 * @property integer $pcu_bank_linked
 * @property integer $pcu_card_linked
 * @property double $pcu_user_balance
 * @property string $pcu_sec_question1
 * @property string $pcu_sec_answer1
 * @property string $pcu_sec_question2
 * @property string $pcu_sec_answer2
 * @property integer $pcu_status
 * @property string $created_at
 * @property string $updated_at
 */
class Userdetails extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */

	public $term_of_service;
	public $image;

	public function tableName()
	{
		return 'pc_userdetails';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(

			array('pcu_email,pcu_mobile,pcu_firstname,pcu_lastname', 'required','on'=>'updateinfo'),
			array('pcu_account_type, pcu_mobile, pcu_status', 'numerical', 'integerOnly'=>true,'on'=>'updateUsers'),
			array('pcu_firstname, pcu_lastname', 'length', 'max'=>32,'on'=>'updateUsers'),
			array('pcu_zipcode', 'length', 'max'=>6,'on'=>'updateUsers'),
			array('pcu_firstname, pcu_lastname, pcu_address1, pcu_email, pcu_zipcode, pcu_mobile, pcu_user_balance', 'required','on'=>'updateUsers'),

			array('pcu_firstname,pcu_dob, pcu_lastname, pcu_address1, term_of_service, pcu_country, pcu_state, pcu_location, pcu_zipcode, pcu_mobile', 'required', 'on'=>'register'),

			//array('pcu_dob', 'date', 'format'=>'d/m/Y','on'=>'register'),

			array('pcu_firstname,pcu_dob, pcu_lastname, pcu_address1, term_of_service, pcu_country, pcu_state, pcu_location, pcu_zipcode, pcu_mobile,pcu_company_name,pcu_trn_no', 'required', 'on'=>'busregister'),

			array('pcu_email', 'required','on'=>'forget'),
			array('pcu_firstname', 'length', 'max'=>32,'on'=>'register'),
			array('pcu_lastname', 'length', 'max'=>32,'on'=>'register'),
			array('pcu_address1', 'length', 'max'=>64,'on'=>'register'),
			array('pcu_email','email','on'=>'register,forget,updateinfo'),
			array('pcu_mobile', 'length', 'max'=>14,'on'=>'register'),

			array('pcu_id, pcu_firstname,pcu_dob, pcu_middlename,pcu_email, pcu_lastname,pcu_mobile_code, pcu_account_type,pcu_account_status, pcu_address1, pcu_address2, pcu_country, pcu_state, pcu_city, pcu_location, pcu_zipcode, pcu_mobile, pcu_mobile_verified, pcu_email_verified, pcu_bank_linked, pcu_card_linked, pcu_user_balance,,pcu_company_name,pcu_trn_no, pcu_sec_question1, pcu_sec_answer1, pcu_sec_question2, pcu_sec_answer2, pcu_status, created_at, updated_at', 'safe', 'on'=>'admin_user_search,register,updateinfo'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'UserRel' => array(self::BELONGS_TO, 'User', 'pcu_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'pcu_id' => 'Pcu',
			'pcu_fullname' => 'Name',
			'pcu_firstname' => 'Firstname',
			'pcu_middlename' => 'Middlename',
			'pcu_lastname' => 'Lastname',
			'pcu_account_type' => 'Account Type ',
			'pcu_account_status' => 'Account Status',
			'pcu_address1' => 'Address1',
			'pcu_dob' => 'Date of Birth',
			'pcu_address2' => 'Address2',
			'pcu_country' => 'Country',
			'pcu_state' => 'State',
			'pcu_city' => 'City',
			'pcu_location' => 'Location',
			'pcu_zipcode' => 'Zipcode',
			'pcu_email' => 'Email',
			'pcu_mobile' => 'Mobile',
			'pcu_mobile_verified' => 'Mobile Verified',
			'pcu_email_verified' => 'Email Verified',
			'pcu_bank_linked' => 'Bank Linked',
			'pcu_card_linked' => 'Card Linked',
			'pcu_user_balance' => 'User Balance',
			'pcu_sec_question1' => 'Security Question1',
			'pcu_sec_answer1' => 'Security Answer1',
			'pcu_sec_question2' => 'Security Question2',
			'pcu_sec_answer2' => 'Security Answer2',
			'pcu_status' => 'Status',
			'created_at' => 'Joined Date',
			'updated_at' => 'Updated At',
			'pcu_company_name' => 'Company Name',
			'pcu_trn_no' => 'Company ID/TRN Number',
			'term_of_service' => 'Terms & conditions',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function admin_user_search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;
		$criteria->with = array('UserRel');
		$criteria->together = true;

		$criteria->compare('pcu_id',$this->pcu_id);
		$criteria->compare('pcu_email',$this->pcu_email,true);
		$criteria->compare('pcu_firstname',$this->pcu_firstname,true);
		$criteria->compare('pcu_middlename',$this->pcu_middlename,true);
		$criteria->compare('pcu_lastname',$this->pcu_lastname,true);
		$criteria->compare('pcu_account_type',$this->pcu_account_type);
		$criteria->compare('pcu_account_status',$this->pcu_account_status);
		$criteria->compare('pcu_address1',$this->pcu_address1,true);
		$criteria->compare('pcu_address2',$this->pcu_address2,true);
		$criteria->compare('pcu_country',$this->pcu_country);
		$criteria->compare('pcu_state',$this->pcu_state);
		$criteria->compare('pcu_email',$this->pcu_email);
		$criteria->compare('pcu_city',$this->pcu_city);
		$criteria->compare('pcu_location',$this->pcu_location);
		$criteria->compare('pcu_zipcode',$this->pcu_zipcode,true);
		$criteria->compare('pcu_mobile',$this->pcu_mobile);
		$criteria->compare('pcu_mobile_verified',$this->pcu_mobile_verified);
		$criteria->compare('pcu_email_verified',$this->pcu_email_verified);
		$criteria->compare('pcu_bank_linked',$this->pcu_bank_linked);
		$criteria->compare('pcu_card_linked',$this->pcu_card_linked);
		$criteria->compare('pcu_user_balance',$this->pcu_user_balance);
		$criteria->compare('pcu_sec_question1',$this->pcu_sec_question1,true);
		$criteria->compare('pcu_sec_answer1',$this->pcu_sec_answer1,true);
		$criteria->compare('pcu_sec_question2',$this->pcu_sec_question2,true);
		$criteria->compare('pcu_sec_answer2',$this->pcu_sec_answer2,true);
		$criteria->compare('pcu_dob',$this->pcu_dob,true);
		$criteria->compare('pcu_status',$this->pcu_status);
		$criteria->compare('created_at',$this->created_at,true);
		$criteria->compare('updated_at',$this->updated_at,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
			'sort'=>array(
                        'defaultOrder'=>'pcu_id DESC',
                    ),
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Userdetails the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	public function beforeSave(){
		if($this->isNewRecord)
			$this->created_at	= date('Y-m-d H:i:s');
		else
			$this->updated_at	= date('Y-m-d H:i:s');

		return true;
	}

	public function getfullname()
	{
		return $this->pcu_firstname." ".$this->pcu_middlename." ".$this->pcu_lastname;
	}
}
